# 🧾 docu-lite
### Zero-dependency HTML doc viewer for Python. 
#### Browse classes and functions with collapsible docstrings in a tidy, readable format.

This is the MVP upload. Coming soon 
  - use your own css file instead of the auto-generated css

Just 100 lines to make HTML for this:

![Capture](https://github.com/user-attachments/assets/bbc3723a-ad19-410e-8e7d-8d09e744b198)
